@@ -15,7 +15,6 @@
 #include <stddef.h>
 #include <sys/types.h>
 #include <string.h>
-#include <unistd.h>
 #include <math.h>
 #include <ctype.h>
 #include "mtxutl.h"
@@ -27,7 +26,10 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #endif
-#ifndef mingw
+#ifndef _MSC_VER
+#include <unistd.h>
+#endif
+#if !defined(mingw) && !defined(_MSC_VER)
 #include <sys/resource.h> // for setstacksize, 2016/Jun
 #include <sys/shm.h> // shared memory
 #include <sys/mman.h> // shm_open
@@ -35,7 +37,7 @@
 
 
 
-#define VERSION "7.407"
+#define VERSION "7.429"
 #define SHOWVERSION reporterr( "%s (%s) Version " VERSION "\nalg=%c, model=%s, amax=%3.1f\n%d thread(s)\n\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
